act.io.armfiles.ARMStandardsFlag
================================

.. currentmodule:: act.io.armfiles

.. autoclass:: ARMStandardsFlag

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ARMStandardsFlag.NO_DATASTREAM
      ~ARMStandardsFlag.OK
   
   